# Extra Examples

The examples in this folder are designed to work with other pHATs and HATs:

* drum_hits.py expects a Drum HAT to be available and the relevant Python library installed

* pov_rainbow.py and spirit_level.py expects an Enviro pHAT to be available and the relevant Python library installed

